@@ -11,20 +11,9 @@ use Cwd 'abs_path';
 
 use File::VirusScan::Result;
 
-sub new
+sub default_arguments
 {
-	my ($class, $conf) = @_;
-
-	if(!$conf->{command}) {
-		croak "Must supply a 'command' config value for $class";
-	}
-
-	my $self = {
-		command => $conf->{command},
-		args    => [ '--mail', '--arc' ],
-	};
-
-	return bless $self, $class;
+	return [qw( --mail --arc)];
 }
 
 sub scan
@@ -66,8 +55,8 @@ File::VirusScan::Engine::Command::BitDefender::BDC - File::VirusScan backend for
 
 =head1 SYNOPSIS
 
-    use File::VirusScanner;
-    my $s = File::VirusScanner->new({
+    use File::VirusScan;
+    my $s = File::VirusScan->new({
 	engines => {
 		'-Command::BitDefender::BDC' => {
 			command => '/path/to/bdc',
@@ -125,4 +114,4 @@ Dave O'Neill (dmo@roaringpenguin.com)
 Copyright (c) 2007 Roaring Penguin Software, Inc.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the terms of the GPL, version 2 or later.
