@@ -11,20 +11,9 @@ use Cwd 'abs_path';
 
 use File::VirusScan::Result;
 
-sub new
+sub default_arguments
 {
-	my ($class, $conf) = @_;
-
-	if(!$conf->{command}) {
-		croak "Must supply a 'command' config value for $class";
-	}
-
-	my $self = {
-		command => $conf->{command},
-		args    => ['--subdir'],
-	};
-
-	return bless $self, $class;
+	return [ '--subdir' ];
 }
 
 sub scan
@@ -65,8 +54,8 @@ File::VirusScan::Engine::Command::ESET::NOD32 - File::VirusScan backend for scan
 
 =head1 SYNOPSIS
 
-    use File::VirusScanner;
-    my $s = File::VirusScanner->new({
+    use File::VirusScan;
+    my $s = File::VirusScan->new({
 	engines => {
 		'-Command::ESET::NOD32' => {
 			command => '/path/to/esets_cli',
@@ -126,4 +115,4 @@ Dusan Zovinec
 Copyright (c) 2007 Roaring Penguin Software, Inc.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the terms of the GPL, version 2 or later.
