@@ -11,22 +11,10 @@ use Cwd 'abs_path';
 
 use File::VirusScan::Result;
 
-sub new
+sub default_arguments
 {
-	my ($class, $conf) = @_;
-
-	if(!$conf->{command}) {
-		croak "Must supply a 'command' config value for $class";
-	}
-
-	my $self = {
-		command => $conf->{command},
-
-		# TODO: should /var/run/aveserver be hardcoded?
-		args => [ '-s', '-p', '/var/run/aveserver' ],
-	};
-
-	return bless $self, $class;
+	# TODO: should /var/run/aveserver be hardcoded?
+	return [ qw( -s -p /var/run/aveserver ) ];
 }
 
 sub scan
@@ -98,8 +86,8 @@ File::VirusScan::Engine::Command::Kaspersky::AVP5 - File::VirusScan backend for
 
 =head1 SYNOPSIS
 
-    use File::VirusScanner;
-    my $s = File::VirusScanner->new({
+    use File::VirusScan;
+    my $s = File::VirusScan->new({
 	engines => {
 		'-Command::Kaspersky::AVP5' => {
 			command => '/path/to/aveclient',
@@ -159,4 +147,4 @@ Enrico Ansaloni
 Copyright (c) 2007 Roaring Penguin Software, Inc.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the terms of the GPL, version 2 or later.
