@@ -167,8 +167,8 @@ File::VirusScan::Engine::Daemon::ClamAV::Clamd - File::VirusScan backend for sca
 
 =head1 SYNOPSIS
 
-    use File::VirusScanner;
-    my $s = File::VirusScanner->new({
+    use File::VirusScan;
+    my $s = File::VirusScan->new({
 	engines => {
 		'-Daemon::ClamAV::Clamd' => {
 			socket_name => '/path/to/clamd.ctl',
@@ -257,4 +257,4 @@ Dave O'Neill (dmo@roaringpenguin.com)
 Copyright (c) 2007 Roaring Penguin Software, Inc.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the terms of the GPL, version 2 or later.
